@@ -1,7 +1,7 @@
-from typing import Dict, Callable
+from typing import Callable, Dict
 
-from .script_kernel import create_script_kernel
 from .notebook_kernel import create_notebook_kernel
+from .script_kernel import create_script_kernel
 
 KERNEL_CREATEORS: Dict[str, Callable[..., str]] = {
     "script": create_script_kernel,
