@@ -3,7 +3,8 @@ from typing import Dict, Iterable
 from .bootstrap import create_bootstrap_code
 
 
-SCRIPT_TEMPLATE: str = """{bootstrap_code}
+SCRIPT_TEMPLATE: str = """{prologue}
+{bootstrap_code}
 
 {script_body}
 """
@@ -15,6 +16,8 @@ def create_script_kernel(
     pkg_dataset: str,
     env_variables: Dict,
     dependencies: Iterable[str],
+    secret_keys: Iterable[str],
+    prologue: str,
     enable_internet: bool = False,
 ) -> str:
     bootstrap_code = create_bootstrap_code(
@@ -22,8 +25,12 @@ def create_script_kernel(
         pkg_dataset=pkg_dataset,
         env_variables=env_variables,
         dependencies=dependencies,
+        secret_keys=secret_keys,
         enable_internet=enable_internet,
     )
     return SCRIPT_TEMPLATE.format(
-        bootstrap_code=bootstrap_code, script_body=script_body, encoding="utf8"
+        bootstrap_code=bootstrap_code,
+        script_body=script_body,
+        prologue=prologue,
+        encoding="utf8",
     )
