@@ -39,6 +39,14 @@ def dataset_prompt() -> List:
     return dataset_sources
 
 
+def extra_dependencies_prompt() -> List:
+    extra_dependencies = []
+    while click.confirm("Would you like to add extra dependencies?"):
+        dependency = click.prompt("dependency")
+        extra_dependencies.append(dependency)
+    return extra_dependencies
+
+
 def init_impl(api: KaggleApi) -> Dict:
     meta_data: Dict[str, Any] = {}
     meta_data["competition"] = competition_prompt(api)
@@ -62,17 +70,17 @@ def init_impl(api: KaggleApi) -> Dict:
     )
     meta_data["dataset_sources"] = dataset_prompt()
     meta_data["competition_sources"] = [meta_data["competition"]]
-    meta_data["enable_constraint"] = click.confirm(
-        "enable_constraint",
-        default=DEFAULT_KKT_CONFIG["meta_data"]["enable_constraint"],
-    )
 
     kkt_config: Dict[str, Any] = {
         "meta_data": meta_data,
     }
+    kkt_config["enable_constraint"] = click.confirm(
+        "enable_constraint", default=DEFAULT_KKT_CONFIG["enable_constraint"]
+    )
     kkt_config["enable_git_tag"] = click.confirm(
         "enable_git_tag", default=DEFAULT_KKT_CONFIG["enable_git_tag"]
     )
+    kkt_config["extra_dependencies"] = extra_dependencies_prompt()
     return kkt_config
 
 
@@ -98,11 +106,11 @@ def confirm_add_package_source(project_name: str):
 
 def add_package_source(project_root_path: Path, project_name: str) -> None:
     pkg_dir_path = project_root_path / "src" / project_name
-    print(pkg_dir_path)
+    click.echo(pkg_dir_path)
     pkg_dir_path.mkdir(parents=True, exist_ok=True)
 
     init_file_path = pkg_dir_path / "__init__.py"
-    print(init_file_path)
+    click.echo(init_file_path)
     init_file_path.touch()
 
 
@@ -120,16 +128,13 @@ def init(
     parser.write(kkt)
 
     project_name = get_project_name(parser)
-    print(project_name)
     if project_name is None:
-        print("no name")
+        click.echo("Project name is Empty")
         return
 
     project_root_path = pyproject_path.parent
     if has_package_source(project_root_path, project_name):
-        print("has")
         return
 
     if confirm_add_package_source(project_name):
-        print("add")
         add_package_source(project_root_path, project_name)
