@@ -1,21 +1,21 @@
-from typing import List, Dict, Optional
-from pathlib import Path
-from .kkt_command import kkt_command
-from ..parser import KktParser, DEFAULT_KKT_CONFIG
-from ..exception import MetaDataNotFound
 from enum import Enum
-
-from kaggle.models.kaggle_models_extended import KernelPushResponse
-from kaggle.models.kernel_push_request import KernelPushRequest
-from kaggle import KaggleApi
+from pathlib import Path
+from typing import Dict, List, Optional
 
 import click
+from kaggle import KaggleApi
+from kaggle.models.kaggle_models_extended import KernelPushResponse
+from kaggle.models.kernel_push_request import KernelPushRequest
+
+from ..exception import MetaDataNotFound
+from ..parser import DEFAULT_KKT_CONFIG, KktParser
+from .kkt_command import kkt_command
+from .. import kernel_proc
 
 
 def status_impl(api: KaggleApi, meta_data: Dict) -> str:
-    user_name = api.config_values[api.CONFIG_NAME_USER]
-    slug = meta_data.get("slug")
-    result = api.kernel_status(user_name, slug)
+    slug = meta_data["slug"]
+    result = kernel_proc.status(api, slug)
 
     message_elms = [f"status: {result['status']}"]
     if result["failureMessage"]:
