@@ -2,10 +2,6 @@ class FoundUncommitedFiles(EnvironmentError):
     pass
 
 
-class AlreadyPushed(EnvironmentError):
-    pass
-
-
 class KktSectionNotFound(EnvironmentError):
     pass
 
@@ -24,3 +20,7 @@ class NotSupportedKernelType(ValueError):
 
 class InvalidTarget(ValueError):
     pass
+
+
+class InstallKernelError(RuntimeError):
+    pass
